function inc=HomogeneousSolutionSigc(nu,sigrat,typ)
% Function to calculate the strength (sigma_c) as a function of the length
%  scale (l_c) based on the homogeneous solution of the phase-field
%  problem.
%
% Input:
% nu - Poisson's coefficient
% sigrat - principal stress ratio (sigma_2/sigma_1), where sigma_1 is the
%          largest axial tensile stress
% typ - 'noEL' or 'EL' depending on the phase-field formulation ('noEL' is
%       the classic formulation, 'EL' is with the elastic threshold)
%
% Output:
% inc - is the multiplicator value: sigma_c = inc * sqrt(E*g_c/l_c), 
%       where E is Young's modulus g_c is the critical energy release
%       rate, l_c is the length scale parameter.

if sigrat>1
    error('Principal stress ratio needs to be lower than 1.')
end


E=1;    % Normalized material constats
lc=1;
gc=1;
gam=nu/(1-2*nu);
glam=E/(2*(1+nu));
lam=E*nu/((1+nu)*(1-2*nu));

C.glam=glam;
C.lam=lam;
C.gc=gc;
C.lc=lc;

deps1=1e-4;
toler=1e-6;

cnt1=1;
 
eps1=0;

cnt1=2;

dsig=1000;

eps1v(1)=0;
eps2v(1)=0;
sig1v(1)=0;
sig2v(1)=0;

while dsig>0 && cnt1<1e6
    eps1=eps1+deps1;
    deps2=1000;
    eps2=eps1*sigrat;
    [d,ai,a]=calcd(eps1,eps2,C,typ);

    cnt2=1;
    while deps2>toler && cnt2<10000
        eps2=eps1*(sigrat*2*glam*(1-d*ai(1))^2+lam*(1-d*a)^2*(sigrat-1))/(2*glam*(1-d*ai(2))^2+lam*(1-d*a)^2*(1-sigrat));  
        [d,ai,a]=calcd(eps1,eps2,C,typ);
        eps2n=eps1*(sigrat*2*glam*(1-d*ai(1))^2+lam*(1-d*a)^2*(sigrat-1))/(2*glam*(1-d*ai(2))^2+lam*(1-d*a)^2*(1-sigrat)); 
        deps2=abs(eps2-eps2n);
        cnt2=cnt2+1;
    end
    [d,ai,a]=calcd(eps1,eps2,C,typ);
    eps1v(cnt1)=eps1;
    eps2v(cnt1)=eps2;

    L=[2*(1-ai(1)*d)^2*glam+lam*(1-a*d)^2 lam*(1-a*d)^2
        lam*(1-a*d)^2 2*(1-ai(2)*d)^2*glam+lam*(1-a*d)^2];
    sig=L*[eps1;eps2];
    

    sig1v(cnt1)=sig(1);
    sig2v(cnt1)=sig(2);
    
    dsig=sig1v(cnt1)-sig1v(cnt1-1);
    cnt1=cnt1+1;
end


plot(eps1v,sig1v)


inc=max(sig1v)/sqrt(lc/E/gc);

return